library(shiny)
library(dplyr)
library(ggplot2)
library(titanic)
titanic <- titanic::titanic_train


ui <- fluidPage(
    theme='main.css',
    column(12, tags$h2('Titanic dataset exploration')),
    sidebarPanel(
        width = 2,
        class='sidebar',
        tags$h4('Customize'),
        sliderInput(
            inputId='ageslider', 
            label='Age range', 
            min=min(titanic$Age, na.rm=T), 
            max=max(titanic$Age, na.rm=T),
            value=c(min(titanic$Age, na.rm=T), max(titanic$Age, na.rm=T))
        ),
        selectInput(
            inputId='genderselect',
            label='Gender',
            choices=c('Male', 'Female'),
            selected=c('Male', 'Female'),
            multiple = TRUE
        )
    ),
    mainPanel(
        fluidRow(
            column(8, tags$div(
                class='card', 
                tags$h3(class='chart-title', 'Avg. age per passenger class'), 
                plotOutput('bar')
            )),
            column(4, tags$div(
                class='card', 
                tags$h3(class='chart-title', 'Gender pie chart'),
                plotOutput('pie')
            ))
        ),
        fluidRow(
            column(12, tags$div(
                class='card', 
                tags$h3(class='chart-title', 'Age histogram'),
                plotOutput('hist')
            ))
        )
    )
)
server <- function(input, output) {
    output$bar <- renderPlot({
        pclass_age_data <- titanic %>%
            filter(Sex %in% tolower(input$genderselect)) %>% 
            select(Pclass, Age) %>%
            filter(Age >= input$ageslider) %>%
            filter(Age <= input$ageslider) %>%
            group_by(Pclass) %>%
            summarise(Age = round(mean(Age, na.rm=TRUE), 2))
        ggplot(data=pclass_age_data, aes(x=Pclass, y=Age)) + 
            geom_bar(stat='identity', fill='#4179ab') + 
            geom_text(aes(label=Age), vjust=-0.3, size=5) + 
            theme_classic()
    })
    output$pie <- renderPlot({
        pie_data <- titanic %>%
            filter(Sex %in% tolower(input$genderselect)) %>% 
            filter(Age >= input$ageslider) %>%
            filter(Age <= input$ageslider) %>%
            select(Sex) %>%
            group_by(Sex) %>%
            count() %>%
            mutate(Midpoint = cumsum(n) - n / 2)
        ggplot(pie_data, aes(x='', y=n, fill=Sex)) + 
            geom_bar(width=1, stat='identity', color='white') + 
            coord_polar('y', start=0) + 
            scale_fill_manual(values=c('#f34a53', '#4179ab')) + 
            theme_void() + 
            theme(legend.position='bottom')
    })
    output$hist <- renderPlot({
        hist_data <- titanic %>%
            filter(Age >= input$ageslider) %>%
            filter(Age <= input$ageslider) %>%
            filter(Sex %in% tolower(input$genderselect)) %>% 
            select(Age)
        ggplot(hist_data, aes(x=Age)) + 
            geom_histogram(bins=20, color='#62aca8', fill='#1e9a95') + 
            theme_classic()
    })
}
shinyApp(ui=ui, server=server)